// src/components/Terminal.tsx
import React, { useEffect, useRef } from 'react';
import { Terminal } from 'xterm';
import { FitAddon } from 'xterm-addon-fit';
import 'xterm/css/xterm.css';

function TerminalComponent (p: {websocket: string|null}) {
    const {websocket} = p
    const terminalRef = useRef<HTMLDivElement>(null);
    const terminal = useRef<Terminal | null>(null);
    const fitAddon = useRef<FitAddon | null>(null);

    useEffect(() => {
        if (terminalRef.current) {
            terminal.current = new Terminal();
            fitAddon.current = new FitAddon();
            terminal.current.loadAddon(fitAddon.current);
            terminal.current.open(terminalRef.current);
            fitAddon.current.fit();
            if (websocket == null){
                
                return ()=>{
                    terminal.current?.dispose();
                }
            }

            const socket = new WebSocket(websocket);

            socket.addEventListener('open', () => {
            });

            socket.addEventListener('message', (event) => {
                terminal.current?.write(JSON.parse(event.data));
            });

            terminal.current.onData((data) => {
                socket.send(JSON.stringify({CommandType: 'insert', Arguments: [data]}));
            });

            return () => {
                terminal.current?.dispose();
                socket.close();
            };
        }
    }, []);

    return <div ref={terminalRef} style={{ width: '100%', height: '100%' }}></div>;
};

export default TerminalComponent;
